<?php
require_once 'classes/Template.php';
require_once 'classes/ValidaSesion.php';

$menu = 0;
$submenu = 0;
$titulo = '';

if (!isset($_SESSION['usuario_id']))
    ValidaSesion::salirPagina();
else {
    if(isset($_SESSION['usuario_id']))
        $objSesion = new ValidaSesion($pdo, $submenu);
    else 
        ValidaSesion::salirPagina();
}
if (isset($objSesion))
    $titulo = $objSesion->nombrePagina();
?>

<!DOCTYPE html>
<html>
    <head>
        <title>Alumnos - <?php echo $titulo; ?></title>
        <?php if ($objSesion->tieneAcceso())
            Template::getCSS();
        else
            Template::getCSS(); ?>
        <style>

            
        </style>
    </head>
    <body>
        <?php $menuObj = new MainMenu($_SESSION["RolUsuario_id"], $menu, $submenu, $pdo);
        $menuObj->printMenu($titulo);
        if ($objSesion->tieneAcceso()) { ?>
        <main class="container-fluid content marco">

        </main>
        <?php } else { ?>
        <main class="container-fluid content marco">
            <div class="row justify-content-center" style="min-height: 600px;">
                <img id="errorImg" class="col-sm-3" src="img/nico_error.svg" />
                <div class="col-sm-9 display-4 d-flex flex-row justify-content-center align-items-center text-center">No tienes acceso a ésta página</div>
            </div>
        </main>
        <?php } ?>
        <div style="isolation: isolate;">
        <?php Template::footer(); ?>
        </div>
        <?php if ($objSesion->tieneAcceso())
            Template::getJS();
        else
            Template::getJS(); ?>
    </body>
</html>